@@ -2,7 +2,7 @@
 from osaft.core.logger import log
 
 # Import API
-from osaft.core.backgroundfields import BackgroundField, WaveTypes
+from osaft.core.backgroundfields import BackgroundField, WaveType
 from osaft.core.fluids import InviscidFluid, ViscoelasticFluid, ViscousFluid
 from osaft.core.solids import ElasticSolid, RigidSolid
 from osaft.plotting.arf.arf_plots import ARFPlot
