@@ -1,14 +1,17 @@
-from typing import Optional, Union
+from typing import Union
 
-from osaft.core.backgroundfields import WaveTypes
+from osaft import log
+from osaft.core.backgroundfields import WaveType
 from osaft.core.fluids import ViscousFluid
 from osaft.core.frequency import Frequency
 from osaft.core.geometries import Sphere
 from osaft.core.helper import StringFormatter as SF
-from osaft.solutions.Doinikov1994Rigid.base import BaseDoinikov1994Rigid
+from osaft.core.variable import ActiveVariable
+from osaft.solutions.base_solution import BaseSolution
+from osaft.solutions.BaseDoinikov1994.base import BaseDoinikov1994
 
 
-class BaseDoinikov1994Compressible(BaseDoinikov1994Rigid):
+class BaseDoinikov1994Compressible(BaseDoinikov1994, BaseSolution):
     """Base class for Doinikov (viscous fluid-viscous sphere; 1994)
 
     :param frequency: Frequency [Hz]
@@ -24,31 +27,58 @@ class BaseDoinikov1994Compressible(BaseDoinikov1994Rigid):
     :param p_0: Pressure amplitude of the field [Pa]
     :param position: Position within the standing wave field [m]
     :param wave_type: Type of wave, travel(l)ing or standing
-    :param N_max: Highest order mode
     """
 
+    # Supported wave_type for the class
+    supported_wavetypes = [WaveType.STANDING, WaveType.TRAVELLING]
+
     def __init__(
         self, frequency: Union[Frequency, float, int],
         radius: Union[Sphere, float, int],
         rho_s: float, c_s: float, eta_s: float, zeta_s: float,
         rho_f: float, c_f: float, eta_f: float, zeta_f: float,
-        p_0: float, wave_type: WaveTypes, position: float,
-        N_max: Optional[int] = 3,
+        p_0: float, wave_type: WaveType, position: float,
     ) -> None:
         """Constructor method
         """
 
-        super().__init__(
-            frequency, radius, rho_s, rho_f, c_f, eta_f, zeta_f,
-            p_0, position, wave_type, N_max,
+        # init of parent class
+        BaseDoinikov1994.__init__(
+            self,
+            frequency=frequency, radius=radius,
+            rho_f=rho_f, c_f=c_f, eta_f=eta_f, zeta_f=zeta_f,
+            p_0=p_0, wave_type=wave_type, position=position,
         )
+        BaseSolution.__init__(self, 'Doinikov1994Compressible')
 
+        # Scatterer
         self.scatterer = ViscousFluid(
             self.frequency, rho_s, c_s, eta_s,
             zeta_s,
         )
 
-    def __str__(self):
+        if type(self) == BaseDoinikov1994Compressible:
+            log.info(repr(self))  # pragma: no cover
+
+        # Dependent Variables
+        self._rho_t = ActiveVariable(
+            self._compute_rho_t,
+            'ratio of densities',
+        )
+        self._rho_t.is_computed_by(self.fluid._rho_f, self.scatterer._rho_f)
+
+    def __repr__(self):  # pragma: no cover
+        return (
+            f'BaseDoinikov1994Rigid(frequency={self.f}, radius={self.R_0}, '
+            f'rho_s={self.rho_s}, c_s={self.rho_f}, eta_s={self.rho_f}, ',
+            f'zeta_s={self.rho_f} ',
+            f'rho_f={self.rho_f}, c_f={self.c_f}, eta_f={self.eta_f}, '
+            f'zeta_f={self.zeta_f}, '
+            f'p_0={self.p_0}, position={self.position} {self.wave_type}, '
+            f'N_max={self.N_max})',
+        )
+
+    def __str__(self):  # pragma: no cover
         out = 'Doinikovs\'s  (1994) model (viscous fluid-viscous sphere)'
         out += ' with the following properties: \n'
         out += SF.get_str_text('Frequency', 'f', self.f, 'Hz')
@@ -113,9 +143,19 @@ class BaseDoinikov1994Compressible(BaseDoinikov1994Rigid):
         return out
 
     # -------------------------------------------------------------------------
-    # Wrappers for Independent sphere Attributes
+    # Wrappers for Independent Scatterer Attributes
     # -------------------------------------------------------------------------
 
+    @property
+    def rho_s(self) -> float:
+        """ Wraps to :attr:`osaft.core.solids.RigidSolid.rho_s`
+        """
+        return self.scatterer.rho_f
+
+    @rho_s.setter
+    def rho_s(self, value: float) -> None:
+        self.scatterer.rho_f = value
+
     @property
     def kappa_s(self) -> float:
         """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.kappa_f`
@@ -123,27 +163,17 @@ class BaseDoinikov1994Compressible(BaseDoinikov1994Rigid):
         return self.scatterer.kappa_f
 
     @property
-    def k_s(self) -> float:
+    def k_s(self) -> complex:
         """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.k_f`
         """
         return self.scatterer.k_f
 
     @property
-    def k_vs(self) -> float:
+    def k_vs(self) -> complex:
         """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.k_v`
         """
         return self.scatterer.k_v
 
-    @property
-    def rho_s(self) -> float:
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.rho_f`
-        """
-        return self.scatterer.rho_f
-
-    @rho_s.setter
-    def rho_s(self, value: float) -> None:
-        self.scatterer.rho_f = value
-
     @property
     def c_s(self) -> float:
         """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.c_f`
