@@ -5,8 +5,7 @@ from typing import Optional, Union
 import numpy as np
 
 from osaft import log
-from osaft.core.backgroundfields import WaveTypes, WrongWaveTypeError
-from osaft.core.basecomposite import BaseSphereFrequencyComposite
+from osaft.core.backgroundfields import WaveType
 from osaft.core.frequency import Frequency
 from osaft.core.functions import conj, pi, sin, xexpexp1
 from osaft.core.geometries import Sphere
@@ -16,7 +15,7 @@ from osaft.solutions.base_arf import BaseARF
 from osaft.solutions.Doinikov1994Rigid.scattering import ScatteringField
 
 
-class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
+class ARF(ScatteringField, BaseARF):
     """ARF class for Doinikov (viscous fluid-rigid sphere; 1994)
 
     .. note::
@@ -55,7 +54,7 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
         rho_f: float, c_f: float,
         eta_f: float, zeta_f: float,
         p_0: float,
-        wave_type: WaveTypes = WaveTypes.STANDING,
+        wave_type: WaveType = WaveType.STANDING,
         position: Optional[float] = None,
         small_particle_limit: bool = True,
         small_viscous_boundary_layer: bool = False,
@@ -67,11 +66,10 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
         """
 
         # init of parent class
-        BaseSphereFrequencyComposite.__init__(self, frequency, radius)
-        ScatteringField.__init__(
-            self, frequency, radius, rho_s, rho_f,
-            c_f, eta_f, zeta_f,
-            p_0, wave_type, position, N_max,
+        super().__init__(
+            frequency=frequency, radius=radius, rho_s=rho_s,
+            rho_f=rho_f, c_f=c_f, eta_f=eta_f, zeta_f=zeta_f,
+            p_0=p_0, wave_type=wave_type, position=position, N_max=N_max,
         )
 
         # independent variables
@@ -94,16 +92,6 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
             large_viscous_boundary_layer,
             'large viscous boundary layer limit',
         )
-
-        # dependent variables
-        self._norm_delta = ActiveVariable(
-            self._compute_norm_delta,
-            'normalized boundary layer thickness',
-        )
-        self._norm_delta.is_computed_by(
-            self.fluid._delta, self.sphere._R_0,
-        )
-
         # Coefficients G_n
         self._G_0 = ActiveVariable(self._compute_G_0, 'G_0')
         self._G_1 = ActiveVariable(self._compute_G_1, 'G_1')
@@ -243,11 +231,10 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
 
         It logs the current values of :attr:`x` and :attr:`x_v`.
 
-        :raises ValueError: Non supported :attr:`~osaft.solutions.\
-Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
+        :raises WrongWaveTypeError: if wrong :attr:`wave_type`
         """
-        if not isinstance(self.wave_type, WaveTypes):
-            raise WrongWaveTypeError
+        # Checking wave_type
+        self.check_wave_type()
 
         log.info(
             'Computing the ARF with Doinikov1994Rigid.\n'
@@ -275,7 +262,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
     def _arf_fastened_small_delta(self) -> float:
         # eq. (7.1) for travelling wave and
         # eq. (6.14) w/ \\delta -> 0 for standing
-        if self.wave_type == WaveTypes.TRAVELLING:
+        if self.wave_type == WaveType.TRAVELLING:
             out = 1 - self.norm_delta
             out *= 1.5 * self.norm_delta
         else:
@@ -286,7 +273,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     def _arf_fastened_large_delta(self) -> float:
         # eq. (7.5) for travelling wave and eq. (7.6) for standing
-        if self.wave_type == WaveTypes.TRAVELLING:
+        if self.wave_type == WaveType.TRAVELLING:
             out = 1 - 1.2 / self.norm_delta
 
             out *= -1.5 * self.norm_delta
@@ -299,7 +286,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     def _arf_small_particle_large_delta(self) -> float:
         # eq. (6.18) for travelling wave and eq. (6.19) for standing
-        if self.wave_type == WaveTypes.TRAVELLING:
+        if self.wave_type == WaveType.TRAVELLING:
             out = (1 - self.rho_t) / self.norm_delta
             out *= -22 / 15
         else:
@@ -311,7 +298,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     def _arf_small_particle_small_delta(self) -> float:
         # eq. (6.13) for travelling wave and eq. (6.14) for standing
-        if self.wave_type == WaveTypes.TRAVELLING:
+        if self.wave_type == WaveType.TRAVELLING:
             out = 2 + 12 * self.rho_t - 21 * self.rho_t**2 + 7 * self.rho_t**3
             out *= -self.norm_delta / (2 + self.rho_t)
             out += (1 - self.rho_t)**2
@@ -329,7 +316,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
         """ Acoustic radiation force for the case where the particle radius
         and the viscous boundary layer are small compared to the wavelength
         """
-        if self.wave_type == WaveTypes.TRAVELLING:
+        if self.wave_type == WaveType.TRAVELLING:
             return self._arf_small_particle_travelling()
         else:
             return self._arf_small_particle_standing()
@@ -605,22 +592,6 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
     def fastened_sphere(self, value):
         self._fastened_sphere.value = value
 
-    @property
-    def norm_delta(self) -> float:
-        """ normalized viscous boundary thickness
-        :math:`\\tilde{\\delta}=\\frac{\\delta}{R_0}`
-        """
-        return self._norm_delta.value
-
-    def _compute_norm_delta(self):
-        return self.delta / self.R_0
-
-    @property
-    def x_0(self) -> float:
-        """ Real part of :attr:`~.x`
-        """
-        return self.x.real
-
 
 if __name__ == '__main__':
     pass
