@@ -3,7 +3,7 @@ from __future__ import annotations
 from typing import Optional, Union
 
 from osaft import log
-from osaft.core.backgroundfields import BackgroundField, WaveTypes
+from osaft.core.backgroundfields import BackgroundField, WaveType
 from osaft.core.basecomposite import BaseSphereFrequencyComposite
 from osaft.core.fluids import InviscidFluid
 from osaft.core.frequency import Frequency
@@ -39,23 +39,24 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
     :param position: Position in the standing wave field [rad]
     """
 
+    # Supported wave_type for the class
+    supported_wavetypes = [WaveType.STANDING, WaveType.TRAVELLING]
+
     def __init__(
         self, frequency: Union[Frequency, float, int],
         radius: Union[Sphere, float, int],
         rho_s: float, c_s: float,
         rho_f: float, c_f: float,
         p_0: float,
-        wave_type: WaveTypes,
+        wave_type: WaveType,
         position: Optional[float] = None,
     ) -> None:
         """Constructor method
         """
 
-        # setting default name
-        self._name = 'Gorkov1962'
-
         # init of parent class
         BaseSphereFrequencyComposite.__init__(self, frequency, radius)
+        BaseSolution.__init__(self, 'Gorkov1962')
 
         # Initialize Components
         self.scatterer = InviscidFluid(self.frequency, rho_s, c_s)
@@ -147,13 +148,20 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
         Computes ARF according to Eq. (10) or (11)
         Checks before computation of assumption of theory small particle
         radius to pressure field wavelength is valid.
+
+        :raises WrongWaveTypeError: if wrong :attr:`wave_type`
         """
+        # Checking wave_type
+        self.check_wave_type()
+
+        # Checking particle size
         if 10 * self.R_0 > self.field.lambda_f:
             text = 'Wavelength is less than 10 times greater than specified '
             text += 'Radius. Theory might not be valid anymore.'
             log.info(text)
 
-        if self.wave_type == WaveTypes.STANDING:
+        # Case
+        if self.wave_type == WaveType.STANDING:
             return self._standing_wave_solution()
         else:
             return self._traveling_wave_solution()
