@@ -3,13 +3,17 @@ from __future__ import annotations
 from typing import Optional, Union
 
 from osaft import log
-from osaft.core.backgroundfields import WaveTypes, WrongWaveTypeError
+from osaft.core.backgroundfields import WaveType, WrongWaveTypeError
 from osaft.core.frequency import Frequency
 from osaft.core.functions import SpecialFunctions as SP
-from osaft.core.functions import conj, full_range, pi, sin
+from osaft.core.functions import conj, pi, sin
 from osaft.core.geometries import Sphere
 from osaft.core.helper import StringFormatter as SF
-from osaft.core.variable import ActiveVariable, PassiveVariable
+from osaft.core.variable import (
+    ActiveListVariable,
+    ActiveVariable,
+    PassiveVariable,
+)
 from osaft.solutions.base_arf import BaseARF
 from osaft.solutions.Yosioka1955.scattering import ScatteringField
 
@@ -32,7 +36,7 @@ class ARF(ScatteringField, BaseARF):
         self, frequency: Union[Frequency, float, int],
         radius: Union[Sphere, float, int],
         rho_s: float, c_s: float, rho_f: float, c_f: float,
-        p_0: float, wave_type: WaveTypes,
+        p_0: float, wave_type: WaveType,
         position: Optional[float] = None, N_max: int = 5,
         small_particle: bool = False, bubble: bool = False,
     ) -> None:
@@ -67,12 +71,12 @@ class ARF(ScatteringField, BaseARF):
             self._compute_F,
             'density-compressibility factor',
         )
-        self._K_n = ActiveVariable(
-            self._reset_coeff,
+        self._K_n = ActiveListVariable(
+            self._compute_K_n,
             'Coefficient K_n',
         )
-        self._M_n = ActiveVariable(
-            self._reset_coeff,
+        self._M_n = ActiveListVariable(
+            self._compute_M_n,
             'Coefficient M_n',
         )
 
@@ -181,9 +185,12 @@ class ARF(ScatteringField, BaseARF):
         approximation for either small particles (Eq. 59, 62) or small bubbles
         (Eq. 68, 73), if the respective options are selected.
 
-        :return: ARF [N]
+        :raises WrongWaveTypeError: if wrong :attr:`wave_type`
         """
 
+        # Checking wave_type
+        self.check_wave_type()
+
         if self.small_particle and self.bubble_solution:
             return self._bubble_arf()
         elif not self.small_particle and self.bubble_solution:
@@ -279,7 +286,7 @@ class ARF(ScatteringField, BaseARF):
         out = 2 * pi * self.rho_f * sum(out)
 
         # Needed because Yosioka has different definition for standing wave
-        if self.wave_type == WaveTypes.STANDING:
+        if self.wave_type == WaveType.STANDING:
             out *= -1
 
         return out
@@ -299,16 +306,10 @@ class ARF(ScatteringField, BaseARF):
                 text += 'Consider using another model approach'
                 log.warning(text)
                 break
-        if self.wave_type == WaveTypes.STANDING:
+        if self.wave_type == WaveType.STANDING:
             out = self._small_particle_standing_wave_solution()
-        elif self.wave_type == WaveTypes.TRAVELLING:
-            out = self._small_particle_traveling_wave_solution()
         else:
-            raise WrongWaveTypeError(
-                'Small particle solution only defined for '
-                'wave_type == WaveTypes.STANDING '
-                'or wave_type == WaveTypes.TRAVELLING',
-            )
+            out = self._small_particle_traveling_wave_solution()
         return out
 
     def _small_particle_traveling_wave_solution(self) -> float:
@@ -355,16 +356,10 @@ class ARF(ScatteringField, BaseARF):
                 log.info(text)
                 break
 
-        if self.wave_type == WaveTypes.STANDING:
+        if self.wave_type == WaveType.STANDING:
             out = self._standing_wave_solution_bubble()
-        elif self.wave_type == WaveTypes.TRAVELLING:
-            out = self._bubble_traveling_wave_solution()
         else:
-            raise WrongWaveTypeError(
-                'Bubble solution only defined for wave_type == '
-                'WaveTypes.STANDING OR wave_type == '
-                'WaveTypes.TRAVELLING',
-            )
+            out = self._bubble_traveling_wave_solution()
         return out
 
     def _bubble_traveling_wave_solution(self) -> float:
@@ -418,15 +413,15 @@ class ARF(ScatteringField, BaseARF):
         """
         Compute density-compressibility factor F
         """
-        if self.wave_type == WaveTypes.STANDING:
+        if self.wave_type == WaveType.STANDING:
             if self.bubble_solution:
                 return self._compute_F_standing_bubble()
             else:
                 return self._compute_F_standing()
 
         elif (
-            self.wave_type == WaveTypes.TRAVELLING
-            and not self.bubble_solution
+                self.wave_type == WaveType.TRAVELLING
+                and not self.bubble_solution
         ):
             return self._compute_F_travelling()
         else:
@@ -467,12 +462,7 @@ class ARF(ScatteringField, BaseARF):
         :param n: mode [-]
         :return: coefficient [m^2/s]
         """
-
-        if n < len(self._K_n.value):
-            return self._K_n.value[n]
-        else:
-            self._compute_K_n(n)
-            return self._K_n.value[n]
+        return self._K_n.item(n)
 
     def M_n(self, n: int) -> complex:
         """Coefficient :math:`M_n` [m^2/s]
@@ -482,36 +472,25 @@ class ARF(ScatteringField, BaseARF):
         :param n: mode [-]
         :return: coefficient [m^2/s]
         """
+        return self._M_n.item(n)
 
-        if n < len(self._M_n.value):
-            return self._M_n.value[n]
-        else:
-            self._compute_M_n(n)
-            return self._M_n.value[n]
-
-    def _compute_K_n(self, N: int) -> None:
+    def _compute_K_n(self, n: int) -> complex:
         """
         Compute K_n according to Eq. (43)
         """
+        out = (-1) ** n / (2 * n + 1)
+        out *= self.k_s * self.B_n(n)
+        out *= SP.d1_besselj(n, self.k_s * self.R_0)
+        return out
 
-        n_old = len(self._K_n.value)
-        for n in full_range(n_old, N):
-            out = (-1) ** n / (2 * n + 1)
-            out *= self.k_s * self.B_n(n)
-            out *= SP.d1_besselj(n, self.k_s * self.R_0)
-            self._K_n.value.append(out)
-
-    def _compute_M_n(self, N: int) -> None:
+    def _compute_M_n(self, n: int) -> complex:
         """
         Compute M_n according to Eq. (42)
         """
-
-        n_old = len(self._M_n.value)
-        for n in full_range(n_old, N):
-            out = (-1) ** n / (2 * n + 1)
-            out *= self.B_n(n)
-            out *= SP.besselj(n, self.k_s * self.R_0)
-            self._M_n.value.append(out)
+        out = (-1) ** n / (2 * n + 1)
+        out *= self.B_n(n)
+        out *= SP.besselj(n, self.k_s * self.R_0)
+        return out
 
 
 if __name__ == '__main__':
