@@ -412,7 +412,7 @@ class BaseScattering(ABC):
             )
 
 
-class BaseScatteringRigidParticle(BaseScattering):
+class BaseScatteringRigidParticle(ABC):
     """ Base class for the Scattering Field for a model with a rigid
     particle that defines the common interface.
 
@@ -421,9 +421,6 @@ class BaseScatteringRigidParticle(BaseScattering):
     :param N_max: End of the infinite series for the scattering coefficients
     """
 
-    def __init__(self, N_max):
-        super().__init__(N_max)
-
     @abstractmethod
     def particle_velocity(self, t: float) -> float:
         """Particle velocity
