@@ -1,6 +1,6 @@
 import unittest
 
-from osaft import Gorkov1962, King1934, WaveTypes, Yosioka1955
+from osaft import Gorkov1962, King1934, WaveType, Yosioka1955
 from osaft.core.backgroundfields import WrongWaveTypeError
 from osaft.core.functions import SpecialFunctions as Sp
 from osaft.core.functions import conj, pi, sin
@@ -37,7 +37,7 @@ class TestARF(BaseTest):
         lamb = self.cls.lambda_rho
         x_s = self.cls.x_s
 
-        if self.wave_type == WaveTypes.STANDING:
+        if self.wave_type == WaveType.STANDING:
             if self.cls.bubble_solution:
                 out = sigma * x_s ** 3 * (3 * lamb - x_s**2)
                 out /= sigma ** 2 * x_s ** 6 + (3 * lamb - x_s ** 2) ** 2
@@ -57,7 +57,7 @@ class TestARF(BaseTest):
                 return out
 
     def small_particle_ARF(self):
-        if self.wave_type == WaveTypes.STANDING:
+        if self.wave_type == WaveType.STANDING:
             if self.cls.bubble_solution:
                 return self._small_bubble_standing()
             else:
@@ -141,7 +141,7 @@ class TestARF(BaseTest):
                 (self.M_n(n) * conj(self.M_n(n + 1))).real / 2
             )
             s += s1 + s2 + s3 + s4
-        if self.cls.wave_type == WaveTypes.STANDING:
+        if self.cls.wave_type == WaveType.STANDING:
             return -s
         return s
 
@@ -201,7 +201,7 @@ class TestARF(BaseTest):
     def test_value_error_F(self):
         # Small Particle
         self.cls.bubble_solution = True
-        self.cls.wave_type = WaveTypes.TRAVELLING
+        self.cls.wave_type = WaveType.TRAVELLING
         self.assertRaises(WrongWaveTypeError, lambda: self.cls.F)
 
     def test_M_n(self):
