@@ -7,7 +7,7 @@ from typing import Any, Optional, Union
 
 import numpy as np
 
-from osaft import WaveTypes
+from osaft import WaveType
 from osaft.core.frequency import Frequency
 from osaft.solutions.base_solution import BaseSolution
 
@@ -386,8 +386,8 @@ class BaseTest(NumericTestCase):
             'position', np.pi / 4, seed, low=0, high=2 * np.pi,
         )
         self._wave_type = ChangingFromList(
-            'wave_type', WaveTypes.STANDING,
-            WaveTypes, seed,
+            'wave_type', WaveType.STANDING,
+            WaveType, seed,
         )
 
         self.test_variables = {
@@ -662,11 +662,11 @@ class BaseTest(NumericTestCase):
         self._position.value = value
 
     @property
-    def wave_type(self) -> WaveTypes:
+    def wave_type(self) -> WaveType:
         return self._wave_type.value
 
     @wave_type.setter
-    def wave_type(self, value: WaveTypes) -> None:
+    def wave_type(self, value: WaveType) -> None:
         self._wave_type.value = value
 
     # -----------------------------------------------------------------------------
